import javax.swing.JInternalFrame;
import javax.swing.JDesktopPane;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.JMenuBar;
import javax.swing.JFrame;
import javax.swing.KeyStroke;
import javax.swing.*;
import java.awt.event.*;
import java.awt.*;

/*
 * MaskEditor.java requires:
 *   MyInternalFrame.java
 */
public class MaskEditor extends JFrame
                               implements ActionListener {
    JDesktopPane desktop;
    ImageWindow myframe;
    public MaskEditor() {
        super("MaskEditor");
	myframe=null;
        //Make the big window be indented 50 pixels from each edge
        //of the screen.
        int inset = 50;
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        setBounds(inset, inset,
                  screenSize.width/2  - inset*2,
                  screenSize.height/2 - inset*2);

        //Set up the GUI.
        desktop = new JDesktopPane(); //a specialized layered pane
       
        setContentPane(desktop);
        setJMenuBar(createMenuBar());

        //Make dragging a little faster but perhaps uglier.
        desktop.setDragMode(JDesktopPane.OUTLINE_DRAG_MODE);
    }

    protected JMenuBar createMenuBar() {
        JMenuBar menuBar = new JMenuBar();

        //Set up the lone menu.
        JMenu menu = new JMenu("File");
        menu.setMnemonic(KeyEvent.VK_D);
        menuBar.add(menu);

        //Set up the first menu item.
        JMenuItem menuItem = new JMenuItem("Load Source");
        menuItem.setMnemonic(KeyEvent.VK_S);
        menuItem.setAccelerator(KeyStroke.getKeyStroke(
                KeyEvent.VK_N, ActionEvent.ALT_MASK));
        menuItem.setActionCommand("L_S");
        menuItem.addActionListener(this);
        menu.add(menuItem);
	menu.add(new JSeparator());
	menuItem = new JMenuItem("Load Target");
        menuItem.setMnemonic(KeyEvent.VK_T);
        menuItem.setAccelerator(KeyStroke.getKeyStroke(
                KeyEvent.VK_T, ActionEvent.ALT_MASK));
        menuItem.setActionCommand("L_T");
        menuItem.addActionListener(this);
        menu.add(menuItem);
	menu.add(new JSeparator());
	menu.add(new JSeparator());
	menuItem = new JMenuItem("Save Masks");
        menuItem.setMnemonic(KeyEvent.VK_S);
        menuItem.setAccelerator(KeyStroke.getKeyStroke(
                KeyEvent.VK_S, ActionEvent.ALT_MASK));
        menuItem.setActionCommand("S_M");
        menuItem.addActionListener(this);
        menu.add(menuItem);
	menu.add(new JSeparator());
	


        //Set up the second menu item.
        menuItem = new JMenuItem("Quit");
        menuItem.setMnemonic(KeyEvent.VK_Q);
        menuItem.setAccelerator(KeyStroke.getKeyStroke(
                KeyEvent.VK_Q, ActionEvent.ALT_MASK));
        menuItem.setActionCommand("quit");
        menuItem.addActionListener(this);
        menu.add(menuItem);

        return menuBar;
    }
    private ExampleFileFilter initFilter(){
	ExampleFileFilter filter = new ExampleFileFilter();
	
	filter.addExtension("ppm");
		
	return filter;
    }
    private String getSingleFile(JFrame parent,boolean opend){
	JFileChooser chooser = new JFileChooser(".");
	ExampleFileFilter filter = initFilter();
	chooser.setMultiSelectionEnabled(false);
	
	
	chooser.setFileFilter(filter);
	int returnVal;
	if(opend){
	    returnVal = chooser.showOpenDialog(parent);
	}else{
	    returnVal = chooser.showSaveDialog(parent);
	}
	if(returnVal == JFileChooser.APPROVE_OPTION) {
	   
	    return (chooser.getSelectedFile().getPath());
	}
	return null;
    }
    //React to menu selections.
    public void actionPerformed(ActionEvent e) {
        if ("L_S".equals(e.getActionCommand())) { //new
            String filename = getSingleFile(this,true);
	    if(filename!=null){
		createFrame(filename,"Source and Target Images");
	    }
        }else if ("L_T".equals(e.getActionCommand())) { //new
            if(myframe!=null){
		String filename = getSingleFile(this,true);
		if(filename!=null){
		    myframe.setTarget(filename);
		}else{
		    JOptionPane.showMessageDialog(this,"Your image file is something wrong !\n"+"Please check your ppm file."+"Use \"convert -quality 100 -compress none -comment \"\" INPUTFILE OUTPUT.ppm\" to convert the image file to ppm.","", JOptionPane.ERROR_MESSAGE);
		    
		}
	    }else{
		JOptionPane.showMessageDialog(this,"You should load Source Image before loading the Target Image.","", JOptionPane.ERROR_MESSAGE);
		
	    }
        }else if ("S_M".equals(e.getActionCommand())) { //new
            if(myframe!=null){
		if(myframe.isReady()){
		String filename = getSingleFile(this,false);
		if(filename!=null)
		    myframe.setSaveMasks(filename);
		
		}else{
		    JOptionPane.showMessageDialog(this,"You should load Source and Target Images and put more than 3 points to save masks.","", JOptionPane.ERROR_MESSAGE);
		}
	    }else{
		JOptionPane.showMessageDialog(this,"You should load Source and Target Images and put more than 3 points to save masks.","", JOptionPane.ERROR_MESSAGE);
	    
	    }
        }else { //quit
            quit();
        }
    }

    //Create a new internal frame.
    protected void createFrame(String filename,String title) {
        //ImageWindow frame = new ImageWindow(filename,title);
	if(myframe!=null){
	    myframe.dispose();
	    myframe=null;
	
	}
        myframe = new ImageWindow(filename,title);
	myframe.setVisible(true); //necessary as of 1.3
        desktop.add(myframe);
        try {
            myframe.setSelected(true);
        } catch (java.beans.PropertyVetoException e) {}
    }

    //Quit the application.
    protected void quit() {
        System.exit(0);
    }

    /**
     * Create the GUI and show it.  For thread safety,
     * this method should be invoked from the
     * event-dispatching thread.
     */
    private static void createAndShowGUI() {
        //Make sure we have nice window decorations.
        JFrame.setDefaultLookAndFeelDecorated(true);

        //Create and set up the window.
        MaskEditor frame = new MaskEditor();
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        //Display the window.
        frame.setVisible(true);
    }

    public static void main(String[] args) {
        //Schedule a job for the event-dispatching thread:
        //creating and showing this application's GUI.
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                createAndShowGUI();
            }
        });
    }
}
